@@ -544,7 +544,8 @@ $LANG11 = array(
     2 => 'Enva-ho a un amic',
     3 => 'Versi per imprimir',
     4 => 'Opcions de la Notcia',
-    5 => 'Format de notcia en PDF'
+    5 => 'Format de notcia en PDF',
+    6 => 'Subscribe to \'%s\''
 );
 
 ###############################################################################
@@ -1056,7 +1057,7 @@ $LANG33 = array(
     34 => 'Entrades',
     35 => 'Hores',
     36 => 'Selecciona el tipus de transmissi',
-    37 => 'Tens com a mnim un plugin installat que afavoreix la sindicaci de contingut. A sota haurs de seleccionar si vols una transmissi de Geeklog o una transmissi d\'un dels plugins.',
+    37 => '',
     38 => 'Error: Falten camps',
     39 => 'Siusplau, omple el Ttol, Descripci i Nom de l\'arxiu de la transmissi.',
     40 => 'Siusplau inclueix el nombre d\'entrades o nombre d\'hores.',
@@ -1071,7 +1072,10 @@ $LANG33 = array(
     49 => 'Feed Logo',
     50 => "Relative to site url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1576,7 +1580,8 @@ $LANG_CONFIG = array(
     'save_changes' => 'Save Changes',
     'reset_form' => 'Reset Form',
     'changes_made' => 'Changes were successfully made to',
-    'title' => 'Configuration Manager'
+    'title' => 'Configuration Manager',
+    'disable' => 'Click to disable this option'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1845,7 +1850,8 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
 );
 
 ?>
\ No newline at end of file
