@@ -547,7 +547,8 @@ $LANG11 = array(
     2 => 'Mail Story to a Friend',
     3 => 'Printable Story Format',
     4 => 'Story Options',
-    5 => 'PDF Story Format'
+    5 => 'PDF Story Format',
+    6 => "Subscribe to '%s'"
 );
 
 ###############################################################################
@@ -1046,7 +1047,7 @@ $LANG33 = array(
     20 => 'Yes',
     21 => 'No',
     22 => '<i>(no feeds)</i>',
-    23 => 'all Stories',
+    23 => 'All Stories',
     24 => 'Feed Editor',
     25 => 'Feed Title',
     26 => 'Limit',
@@ -1060,7 +1061,7 @@ $LANG33 = array(
     34 => 'Entries',
     35 => 'Hours',
     36 => 'Select type of feed',
-    37 => 'You have at least one plugin installed that supports content syndication. Below you will need to select whether you want to create a Geeklog feed or a feed from one of the plugins.',
+    37 => '',
     38 => 'Error: Missing Fields',
     39 => 'Please fill in the Feed Title, Description, and Filename.',
     40 => 'Please enter a  number of entries or number of hours.',
@@ -1075,7 +1076,10 @@ $LANG33 = array(
     49 => 'Feed Logo',
     50 => "Relative to site url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1257,7 +1261,10 @@ $LANG_DB_BACKUP = array(
     'do_backup' => 'Do Backup',
     'backup_successful' => 'Database back up was successful.',
     'db_explanation' => 'To create a new backup of your site\'s database, click on "Create New" above. Click on a file name to download that backup.',
-    'not_found' => "Incorrect path or mysqldump utility not executable.<br' . XHTML . '> Check <strong>mysqldump_path</strong> definition in the Configuration.<br' . XHTML . '> Path currently defined as: <var>{$_DB_mysqldump_path}</var>",
+    'not_found' => 'Incorrect path, security restriction in effect or mysqldump utility not executable.<br'
+                    . XHTML . '> Check <strong>mysqldump_path</strong> definition in the Configuration.<br'
+                    . XHTML . '> Check <a href="http://www.php.net/manual/en/features.safe-mode.php#ini.open-basedir">open_basedir</a> settings in PHP.<br'
+                    . XHTML . "> Path currently defined as: <var>{$_DB_mysqldump_path}</var>",
     'zero_size' => 'Backup Failed: Filesize was 0 bytes',
     'path_not_found' => "{$_CONF['backup_path']} does not exist or is not a directory",
     'no_access' => "ERROR: Directory {$_CONF['backup_path']} is not accessible.",
@@ -1558,6 +1565,46 @@ $LANG_trackbackcodes = array(
     -1  => 'Trackback Disabled'
 );
 
+################################################################################
+# Localization of the securiy test (admin/sectest.php)
+
+$LANG_SECTEST = array(
+     1 => 'Your ',
+     2 => ' is reachable from the web.',
+     3 => 'This is a security risk and should be fixed!',
+     4 => 'Good! Your ',
+     5 => ' is not reachable from the web.',
+     6 => 'Got an HTTP result code ',
+     7 => ' when trying to test your ',
+     8 => '. Not sure what to make of it ...',
+     9 => 'You should really remove the install directory ',
+    10 => ' once you have your site up and running without any errors.',
+    11 => ' Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
+    12 => 'Good! You seem to have removed the install directory already.',
+    13 => 'You still have not changed the <strong>default password</strong> from "password" on ',
+    14 => ' Root user account(s).',
+    15 => 'Good! You seem to have changed the default account password already.',
+    16 => 'Geeklog Security Check',
+    17 => 'Results of the Security Check',
+    18 => '"public_html" should never be part of your site\'s URL.',
+    19 => ' Please read the part about public_html in the ',
+    20 => 'installation instructions',
+    21 => ' again and change your setup accordingly before you proceed.',
+    22 => 'logs directory',
+    23 => 'plugins directory',
+    24 => 'system directory',
+    25 => 'backups directory',
+    26 => 'Failed to create a temporary file in your backups directory. Check your directory permissions!',
+    27 => 'data directory',
+    28 => 'Failed to create a temporary file in your data directory. Check your directory permissions!',
+    29 => 'Everything seems to be in order.',
+    30 => 'Please fix the above issues before using your site!',
+    31 => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
+    32 => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) ',
+    33 => ' mailing list and/or use the ',
+    34 => ' option in your Admin menu from time to time to check for available updates.',
+);
+
 ################################################################################
 # Localization of the Admin Configuration UI
 
@@ -1570,7 +1617,9 @@ $LANG_CONFIG = array(
     'save_changes'  => 'Save Changes',
     'reset_form'    => 'Reset Form',
     'changes_made'  => 'Changes were successfully made to',
-    'title'         => 'Configuration Manager'
+    'title'         => 'Configuration Manager',
+    'disable'       => 'Click to disable this option',
+    'enable'        => 'Enable'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1846,7 +1895,8 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
 );
 
 ?>
