@@ -547,7 +547,8 @@ $LANG11 = array(
     2 => 'Invia l\'Articolo a un amico',
     3 => 'Articolo in Formato Stampabile',
     4 => 'Opzioni',
-    5 => 'Articolo in Formato PDF'
+    5 => 'Articolo in Formato PDF',
+    6 => 'Subscribe to \'%s\''
 );
 
 ###############################################################################
@@ -1059,7 +1060,7 @@ $LANG33 = array(
     34 => 'Elementi',
     35 => 'Ore',
     36 => 'Seleziona il tipo del feed',
-    37 => 'Hai almeno un plug-in installato che supporta la content syndication. Sotto devi selezionare se vuoi creare un feed Geeklog o un feed da uno dei plug-in.',
+    37 => '',
     38 => 'Errore: Campi Mancanti',
     39 => 'Prego inserire Titolo Feed, Descrizione e Nome File.',
     40 => 'Prego inserire un numero di elementi o un numero di ore.',
@@ -1074,7 +1075,10 @@ $LANG33 = array(
     49 => 'Feed Logo',
     50 => "Relative to site url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1579,7 +1583,8 @@ $LANG_CONFIG = array(
     'save_changes' => 'Save Changes',
     'reset_form' => 'Reset Form',
     'changes_made' => 'Changes were successfully made to',
-    'title' => 'Configuration Manager'
+    'title' => 'Configuration Manager',
+    'disable' => 'Click to disable this option'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1848,7 +1853,8 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
 );
 
 ?>
\ No newline at end of file
