@@ -546,7 +546,8 @@ $LANG11 = array(
     2 => 'Wylij Znajomemu',
     3 => 'Wersja Do Wydruku',
     4 => 'Opcje Artykuu',
-    5 => 'Format PDF'
+    5 => 'Format PDF',
+    6 => 'Subscribe to \'%s\''
 );
 
 ###############################################################################
@@ -1058,7 +1059,7 @@ $LANG33 = array(
     34 => 'Tytuw',
     35 => 'Godzin',
     36 => 'Wybierz rodzaj pliku',
-    37 => 'Masz zainstalowany co najmniej jeden plugin zarzdzajcy syndykacj treci. Poniej naley wybra opcj czy chcesz stworzy plik Geeklogowy czy te plik dla jednego z pluginw.',
+    37 => '',
     38 => 'Bd: Brakujce Pola',
     39 => 'Wpisz Tytu Pliku, Opis i Nazw Pliku.',
     40 => 'Prosz poda liczb tytuw lub czas w godzinach.',
@@ -1073,7 +1074,10 @@ $LANG33 = array(
     49 => 'Feed Logo',
     50 => "Relative to site url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1578,7 +1582,8 @@ $LANG_CONFIG = array(
     'save_changes' => 'Save Changes',
     'reset_form' => 'Reset Form',
     'changes_made' => 'Changes were successfully made to',
-    'title' => 'Configuration Manager'
+    'title' => 'Configuration Manager',
+    'disable' => 'Click to disable this option'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1847,7 +1852,8 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
 );
 
 ?>
\ No newline at end of file
