@@ -32,7 +32,7 @@
 // |                                                                           |
 // +---------------------------------------------------------------------------+
 //
-// $Id: submit.php,v 1.122 2008/03/24 18:36:52 dhaun Exp $
+// $Id: submit.php,v 1.123 2008/07/07 18:24:00 dhaun Exp $
 
 require_once 'lib-common.php';
 require_once $_CONF['path_system'] . 'lib-story.php';
@@ -91,7 +91,7 @@ function submissionform($type='story', $mode = '', $topic = '')
             $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
             return $retval;
         } else {
-            if(!function_exists(CUSTOM_MOBILE_is_cellular) || !CUSTOM_MOBILE_is_cellular()) {
+            if(!function_exists('CUSTOM_MOBILE_is_cellular') || !CUSTOM_MOBILE_is_cellular()) {
                 $retval .= COM_startBlock($LANG12[19])
                         . $LANG12[9]
                         . COM_endBlock();
@@ -294,7 +294,7 @@ function savestory ($A)
 
     COM_updateSpeedlimit ('submit');
 
-    $result = $story->SaveSubmission();
+    $result = $story->saveSubmission();
     if( $result == STORY_NO_ACCESS_TOPIC )
     {
         // user doesn't have access to this topic - bail
