@@ -1,4 +1,9 @@
 <?php
+
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'custom_cellular.php') !== false) {
+    die('This file can not be used on its own!');
+}
+
 /*
  * Geeklog hack for cellular phones.
  * Copyright (c) 2006 - 2008 Tatsumi Imai(http://im-ltd.ath.cx)
@@ -15,6 +20,7 @@ $CUSTOM_MOBILE_CONF['force_cut_table'] = true; // 強制的にテーブルを削
 $CUSTOM_MOBILE_CONF['cut_comment'] = true; // コメントを削除する
 $CUSTOM_MOBILE_CONF['convert_to_sjis'] = true; // SJISに変換する
 $CUSTOM_MOBILE_CONF['host_charset'] = "UTF-8"; // サーバはUTF-8
+$CUSTOM_MOBILE_CONF['refresh_use_location'] = true; // refreshにLocationヘッダを使用する
 /**
  * 画像の縮小用パラメータ
  */
@@ -36,6 +42,9 @@ $CUSTOM_MOBILE_CONF['gc_maxlifetime'] = 1440; //
 $CUSTOM_MOBILE_CONF['gc_probability'] = "1"; //
 $CUSTOM_MOBILE_CONF['gc_divisor'] = "10"; //
 
+/* 暫定的に mobile_3g の使用（XHTMLの使用）を抑制 */
+$CUSTOM_MOBILE_CONF['use_xhtml_for_3g'] = false; /* falseに固定 */
+
 $CUSTOM_MOBILE_UA = 0;
 
 define("MOBILE_3G", 16);
@@ -56,7 +65,7 @@ define("MOBILE_UA_WM_3G", 22);
 
 // 補助URL
 define("RESIZER", "/imageresizer.php");
-define("BLOCKS", "/mobileblocks.php");
+define("BLOCKS", $_CONF['site_url'] . "/mobileblocks.php");
 
 // ユーザエージェントを解析して端末のタイプを判定する
 function _mobile_parse_ua()
@@ -246,14 +255,25 @@ function CUSTOM_MOBILE_debug($msg) {
 // そこでlib-commonのCOM_refresh()をハックする。
 function CUSTOM_refresh($url)
 {
-    global $LANG05;
+    global $LANG05,$CUSTOM_MOBILE_CONF;
     $msg = mb_convert_encoding($LANG05['5'], 'sjis-win', 
                                mb_detect_encoding($LANG05['5'], "UTF-8,EUC-JP,JIS,sjis-win"));
     if(CUSTOM_MOBILE_is_cellular()) {
-        return "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"" .
-            "\"http://www.w3.org/TR/html4/loose.dtd\">\n" .
-            "<html><head><title>$msg</title></head>" .
-            "<body><a href=\"$url\">$msg</a></body></html>\n";
+        if($CUSTOM_MOBILE_CONF['refresh_use_location']) {
+            $sepa = '?';
+            if (strpos($url, '?') > 0)
+            {
+                $sepa = '&amp;';
+            }
+            $location_url = 'Location: ' . $url . $sepa . SID;
+            header( $location_url );
+            exit;
+        } else {
+            return "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"" .
+                "\"http://www.w3.org/TR/html4/loose.dtd\">\n" .
+                "<html><head><title>$msg</title></head>" .
+                "<body><a href=\"$url\">$msg</a></body></html>\n";
+        }
     } else {
         return "<html><head><meta http-equiv=\"refresh\" content=\"0; URL=$url\"></head></html>\n";
     }
@@ -426,7 +446,15 @@ function _mobile_output_handler($content, $status)
     }
 
     if(CUSTOM_MOBILE_is_3g()) {
-        header("Content-type: application/xhtml+xml");
+// ---------------------------------------->>
+//        header("Content-type: application/xhtml+xml");
+// ----------------------------------------||
+        if($CUSTOM_MOBILE_CONF['use_xhtml_for_3g']) {
+            header ("Content-type: application/xhtml+xml");
+        } else {
+            header ('Content-Type: text/html; charset=' . "Shift_JIS");
+        }
+// ----------------------------------------<<
     } else {
         header ('Content-Type: text/html; charset=' . "Shift_JIS");
     }
@@ -652,14 +680,28 @@ if(CUSTOM_MOBILE_is_cellular()) {
 
     // ケータイ用のテーマを使用
     if(CUSTOM_MOBILE_is_3g()) {
-        $_CONF['theme'] = 'mobile_3g';
-        $_POST['usetheme'] = 'mobile_3g';
-        $_USER['theme'] = 'mobile_3g';
+// ---------------------------------------->>
+//        $_CONF['theme'] = 'mobile_3g';
+//        $_POST['usetheme'] = 'mobile_3g';
+//        $_USER['theme'] = 'mobile_3g';
+//        if($CUSTOM_MOBILE_CONF['use_xhtml_for_3g']) {
+//            define('XHTML', ' /');
+//        } else {
+//            define('XHTML', '');
+//        }
+// ----------------------------------------||
         if($CUSTOM_MOBILE_CONF['use_xhtml_for_3g']) {
-            define('XHTML', '/');
+           $_CONF['theme'] = 'mobile_3g';
+           $_POST['usetheme'] = 'mobile_3g';
+           $_USER['theme'] = 'mobile_3g';
+            define('XHTML', ' /');
         } else {
+            $_CONF['theme'] = 'mobile';
+            $_POST['usetheme'] = 'mobile';
+            $_USER['theme'] = 'mobile';
             define('XHTML', '');
         }
+// ----------------------------------------<<
     } else {
         $_CONF['theme'] = 'mobile';
         $_POST['usetheme'] = 'mobile';
